Date: 01 4, 2002 12:15:47 PM

# strspellcompare

## Purpose

Measure the spelling "distance" between wordString1 and wordString2.

## Syntax

returnedNumber = strspellcompare(wordString1, wordString2)

returnedNumber - type: int
wordString1 - type: str
wordString2 - type: str

## Returns

## Remarks

The smaller the number returned, indicates the fewer amount of corrections necessary to get from one word string to the other.

## Example

## See Also

spellcandidates, strspellcandidate, spellcorrect, spellword, Spelling Functions